@@ -37,10 +37,9 @@ var(a::QQRelPowerSeriesRing) = a.S
 max_precision(R::QQRelPowerSeriesRing) = R.prec_max
 
 function normalise(a::QQRelPowerSeriesRingElem, len::Int)
-  if len > 0
-    c = QQFieldElem()
-    @ccall libflint.fmpq_poly_get_coeff_fmpq(c::Ref{QQFieldElem}, a::Ref{QQRelPowerSeriesRingElem}, (len - 1)::Int)::Nothing
-  end
+  len <= 0 && return len
+  c = QQFieldElem()
+  @ccall libflint.fmpq_poly_get_coeff_fmpq(c::Ref{QQFieldElem}, a::Ref{QQRelPowerSeriesRingElem}, (len - 1)::Int)::Nothing
   while len > 0 && iszero(c)
     len -= 1
     if len > 0
