@@ -170,21 +170,25 @@ function -(x::ZZMatrix)
   return z
 end
 
-###############################################################################
+################################################################################
 #
-#   transpose
+#  Transpose
 #
-###############################################################################
+################################################################################
 
-function transpose(x::ZZMatrix)
-  z = similar(x, ncols(x), nrows(x))
-  @ccall libflint.fmpz_mat_transpose(z::Ref{ZZMatrix}, x::Ref{ZZMatrix})::Nothing
-  return z
+function transpose(a::ZZMatrix)
+  z = similar(a, ncols(a), nrows(a))
+  return transpose!(z, a)
 end
 
-function transpose!(A::ZZMatrix, B::ZZMatrix)
-  @ccall libflint.fmpz_mat_transpose(A::Ref{ZZMatrix}, B::Ref{ZZMatrix})::Nothing
-  return A
+function transpose!(a::ZZMatrixOrPtr)
+  @req is_square(a) "Matrix must be a square matrix"
+  return transpose!(a, a)
+end
+
+function transpose!(z::ZZMatrixOrPtr, a::ZZMatrixOrPtr)
+  @ccall libflint.fmpz_mat_transpose(z::Ref{ZZMatrix}, a::Ref{ZZMatrix})::Nothing
+  return z
 end
 
 ###############################################################################
