@@ -40,18 +40,16 @@ var(a::FqPolyRepAbsPowerSeriesRing) = a.S
 max_precision(R::FqPolyRepAbsPowerSeriesRing) = R.prec_max
 
 function normalise(a::FqPolyRepAbsPowerSeriesRingElem, len::Int)
+  len <= 0 && return len
   ctx = base_ring(a)
-  if len > 0
-    c = base_ring(a)()
-    @ccall libflint.fq_poly_get_coeff(c::Ref{FqPolyRepFieldElem}, a::Ref{FqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqPolyRepField})::Nothing
-  end
+  c = base_ring(a)()
+  @ccall libflint.fq_poly_get_coeff(c::Ref{FqPolyRepFieldElem}, a::Ref{FqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqPolyRepField})::Nothing
   while len > 0 && iszero(c)
     len -= 1
     if len > 0
       @ccall libflint.fq_poly_get_coeff(c::Ref{FqPolyRepFieldElem}, a::Ref{FqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqPolyRepField})::Nothing
     end
   end
-
   return len
 end
 
