@@ -40,18 +40,16 @@ var(a::FqAbsPowerSeriesRing) = a.S
 max_precision(R::FqAbsPowerSeriesRing) = R.prec_max
 
 function normalise(a::FqAbsPowerSeriesRingElem, len::Int)
+  len <= 0 && return len
   ctx = base_ring(a)
-  if len > 0
-    c = base_ring(a)()
-    @ccall libflint.fq_default_poly_get_coeff(c::Ref{FqFieldElem}, a::Ref{FqAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqField})::Nothing
-  end
+  c = base_ring(a)()
+  @ccall libflint.fq_default_poly_get_coeff(c::Ref{FqFieldElem}, a::Ref{FqAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqField})::Nothing
   while len > 0 && iszero(c)
     len -= 1
     if len > 0
       @ccall libflint.fq_default_poly_get_coeff(c::Ref{FqFieldElem}, a::Ref{FqAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{FqField})::Nothing
     end
   end
-
   return len
 end
 
