@@ -40,18 +40,16 @@ var(a::fqPolyRepAbsPowerSeriesRing) = a.S
 max_precision(R::fqPolyRepAbsPowerSeriesRing) = R.prec_max
 
 function normalise(a::fqPolyRepAbsPowerSeriesRingElem, len::Int)
+  len <= 0 && return len
   ctx = base_ring(a)
-  if len > 0
-    c = base_ring(a)()
-    @ccall libflint.fq_nmod_poly_get_coeff(c::Ref{fqPolyRepFieldElem}, a::Ref{fqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{fqPolyRepField})::Nothing
-  end
+  c = base_ring(a)()
+  @ccall libflint.fq_nmod_poly_get_coeff(c::Ref{fqPolyRepFieldElem}, a::Ref{fqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{fqPolyRepField})::Nothing
   while len > 0 && iszero(c)
     len -= 1
     if len > 0
       @ccall libflint.fq_nmod_poly_get_coeff(c::Ref{fqPolyRepFieldElem}, a::Ref{fqPolyRepAbsPowerSeriesRingElem}, (len - 1)::Int, ctx::Ref{fqPolyRepField})::Nothing
     end
   end
-
   return len
 end
 
