@@ -783,7 +783,7 @@ end
 
   N = zero_matrix(QQ, 2, 1)
   C = solve_init(N)
-  b = zeros(QQ, 2)
+  b = [zero(QQ), zero(QQ)]
   fl, x, K = @inferred can_solve_with_solution_and_kernel(C, b, side = :right)
   @test fl
   @test N*x == b
@@ -793,7 +793,7 @@ end
 
   N = zero_matrix(QQ, 1, 2)
   C = solve_init(N)
-  b = zeros(QQ, 1)
+  b = [zero(QQ)]
   fl, x, K = @inferred can_solve_with_solution_and_kernel(C, b, side = :right)
   @test fl
   @test N*x == b
